@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 package com.openexchange.pns.json;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import org.json.JSONArray;
 import org.json.JSONException;
@@ -32,6 +33,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
 import com.openexchange.log.LogProperties;
 import com.openexchange.pns.DefaultPushSubscription;
+import com.openexchange.pns.KnownTransport;
 import com.openexchange.pns.PushExceptionCodes;
 import com.openexchange.pns.PushNotifications;
 import com.openexchange.pns.PushSubscriptionRegistry;
@@ -75,9 +77,16 @@ public class SubscribeAction extends AbstractPushJsonAction {
         if (Strings.isEmpty(client)) {
             throw AjaxExceptionCodes.MISSING_FIELD.create("client");
         }
-
         String token = requireStringField("token", jRequestBody);
         String transportId = requireStringField("transport", jRequestBody);
+        List<OXException> warnings = null;
+        if (transportId.toUpperCase().equals(KnownTransport.GCM.name())) {
+            transportId = KnownTransport.FCM.name().toLowerCase();
+            // Add a warning if the subscription transport is GCM and set it to FCM
+            // After GCM is completely dropped, we should simply throw an exception and return with 400
+
+            warnings = Collections.singletonList(AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create("service", transportId));
+        }
         JSONArray jTopics = requireArrayField("topics", jRequestBody);
 
         List<String> topics = new ArrayList<>(jTopics.length());
@@ -105,7 +114,7 @@ public class SubscribeAction extends AbstractPushJsonAction {
             retry = doSubscribe(subscription, subscriptionRegistry);
         } while (retry);
 
-        return new AJAXRequestResult(new JSONObject(2).put("success", true), "json");
+        return new AJAXRequestResult(new JSONObject(2).put("success", true), "json").addWarnings(warnings);
     }
 
     private boolean doSubscribe(DefaultPushSubscription subscription, PushSubscriptionRegistry subscriptionRegistry) throws OXException {
