@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,8 @@
 
 package com.openexchange.pns.json;
 
+import java.util.Collections;
+import java.util.List;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -28,6 +30,7 @@ import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
 import com.openexchange.pns.DefaultPushSubscription;
+import com.openexchange.pns.KnownTransport;
 import com.openexchange.pns.PushSubscriptionRegistry;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.server.ServiceLookup;
@@ -71,23 +74,35 @@ public class UnsubscribeAction extends AbstractPushJsonAction {
 
         String token = requireStringField("token", jRequestBody);
         String transportId = requireStringField("transport", jRequestBody);
+        List<OXException> warnings = null;
+        if (transportId.toUpperCase().equals(KnownTransport.GCM.name())) {
+            transportId = KnownTransport.FCM.name().toLowerCase();
+            // Add a warning if the subscription transport is GCM and set it to FCM
+            // After GCM is completely dropped, we should simply throw an exception and return with 400
 
-        DefaultPushSubscription.Builder builder = DefaultPushSubscription.builder()
-            .client(client)
-            .contextId(session.getContextId())
-            .token(token)
-            .transportId(transportId)
-            .userId(session.getUserId());
-        DefaultPushSubscription subscription = builder.build();
+            warnings = Collections.singletonList(AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create("service", transportId));
+        }
 
-        subscriptionRegistry.unregisterSubscription(subscription);
+        subscriptionRegistry.unregisterSubscription(createSubDesc(client, session, token, transportId));
+        if (transportId.toLowerCase().equals("gcm")) {
+        	subscriptionRegistry.unregisterSubscription(createSubDesc(client, session, token, "fcm"));
+        }
 
-        return new AJAXRequestResult(new JSONObject(2).put("success", true), "json");
+        return new AJAXRequestResult(new JSONObject(2).put("success", true), "json").addWarnings(warnings);
     }
 
     @Override
     public String getAction() {
         return "unsubscribe";
     }
+    
+    private static DefaultPushSubscription createSubDesc(String client, ServerSession session, String token, String transportId) {
+        return DefaultPushSubscription.builder()
+                .client(client)
+                .contextId(session.getContextId())
+                .token(token)
+                .transportId(transportId)
+                .userId(session.getUserId()).build();
+    }
 
 }
