@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,15 +23,16 @@ package com.openexchange.pns.transport.apns_http2.util;
 
 import static com.openexchange.java.Autoboxing.I;
 import java.io.UnsupportedEncodingException;
+import java.time.Instant;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.databind.ObjectMapper;
-import com.turo.pushy.apns.DeliveryPriority;
-import com.turo.pushy.apns.PushType;
-import com.turo.pushy.apns.util.SimpleApnsPushNotification;
+import com.eatthepath.pushy.apns.DeliveryPriority;
+import com.eatthepath.pushy.apns.PushType;
+import com.eatthepath.pushy.apns.util.SimpleApnsPushNotification;
 
 
 /**
@@ -93,7 +94,7 @@ public class ApnsHttp2Notification extends SimpleApnsPushNotification {
             aps = new HashMap<>();
             alert = new HashMap<>();
             priority = DeliveryPriority.IMMEDIATE;
-            expiration = DEFAULT_EXPIRATION_PERIOD_MILLIS;
+            expiration = DEFAULT_EXPIRATION_PERIOD.toMillis();
         }
 
         public Builder mutableContent(boolean mutable) {
@@ -263,7 +264,7 @@ public class ApnsHttp2Notification extends SimpleApnsPushNotification {
         public ApnsHttp2Notification build() {
             root.put("aps", aps);
             aps.put("alert", alert);
-            
+
             return new ApnsHttp2Notification(token, topic, root, expiration < 0 ? null : new Date(System.currentTimeMillis() + expiration), priority, pushType, collapseId, uuid);
         }
     }
@@ -286,7 +287,7 @@ public class ApnsHttp2Notification extends SimpleApnsPushNotification {
      * will assign a unique identifier automatically
      */
     public ApnsHttp2Notification(String token, String topic, Map<String, Object> payload, Date invalidationTime, DeliveryPriority priority, PushType pushType, String collapseId, UUID apnsId) {
-        super(token, topic, maptoString(payload), invalidationTime, priority, pushType, collapseId, apnsId);
+        super(token, topic, maptoString(payload), Instant.ofEpochMilli(invalidationTime.getTime()), priority, pushType, collapseId, apnsId);
     }
 
 }
